@@ -132,7 +132,10 @@ if (typeof django_datatables === 'undefined') {
 
             this.badge_string = function (key) {
                 let result = this.calcs[key]
-                if (result[0] === result[1]) {
+                if (result == undefined){
+                    return '-'
+                }
+                else if (result[0] === result[1]) {
                     return result[0].toString()
                 } else {
                     return result[0].toString() + ' / ' + result[1].toString()
@@ -140,7 +143,10 @@ if (typeof django_datatables === 'undefined') {
             }
 
             this.badge_colour = function (key) {
-                if (this.calcs[key][0] > 0) {
+                if (this.calcs[key] == undefined){
+                    return ['badge-secondary', 'badge-primary']
+                }
+                else if (this.calcs[key][0] > 0) {
                     return ['badge-primary', 'badge-secondary']
                 } else {
                     return ['badge-secondary', 'badge-primary']
@@ -414,21 +420,24 @@ if (typeof django_datatables === 'undefined') {
             Replace: function (column, params, table) {
                 this.reg_exp = RegExp(params.var, 'g')
                 django_datatables.BaseProcessAjaxData.call(this, column, params, table)
-
+                if (this.params.null_value === undefined){
+                    this.null_value = ''
+                }
+                else{
+                    this.null_value = this.params.null_value
+                }
                 this.convert = function (current, value) {
+                    var replacement = value
+                    if (this.field_array && replacement != null){
+                        replacement = value[params.index]
+                    }
+                    if (replacement == null){
+                        return this.null_value;
+                    }
                     if (params.html === undefined) {
-                        if (this.field_array) {
-                            return current.replace(params.var, value[params.index])
-                        } else {
-                            return current.replace(params.var, value)
-                        }
-
+                        return current.replace(this.reg_exp, replacement)
                     } else {
-                        if (this.field_array) {
-                            return params.html.replace(params.var, value[params.index])
-                        } else {
-                            return params.html.replace(params.var, value)
-                        }
+                        return params.html.replace(this.reg_exp, replacement)
                     }
                 }.bind(this)
             },
@@ -499,7 +508,6 @@ if (typeof django_datatables === 'undefined') {
             this.table_id = html_id
 
             django_datatables.DataTables[html_id] = this
-            if (typeof (mobile) == 'undefined') mobile = false;
             for (i = 0; i < tablesetup.colOptions.length; i++) {
                 if (tablesetup.colOptions[i]['render'] != undefined) {
                     tablesetup.tableOptions.columnDefs[i].render = new django_datatables.column_render(i, tablesetup.colOptions[i]['render'], this)
